
History
=======

1.2
---

- Use ``yafowil.utils.entry_point`` decorator.
  [rnix]

1.1.2
-----

- Docs
  [jensens]

1.1.1
-----

- Provide translate callable for pyramid. soft dependency
  [rnix, 2012-04-24]

1.1
---

- use entry point for registration of webob preprocessor. depend on YAFOWIL 1.3
  [jensens, 2012-03-19]

1.0
---

- made it work
  [jensens, rnix, et al, 2010-12-27]
